==> com.liferay.app.builder.web-1.0.2.jar: META-INF/resources/js/App.es.js <==
Liferay.Loader.define("app-builder-web@1.0.2/js/App.es", ['module', 'exports', 'require', '@frontend-taglib-clay$clayui/modal', 'frontend-js-react-web$react', 'frontend-js-react-web$react-dnd', 'frontend-js-react-web$react-dnd-html5-backend', 'app-builder-web$react-router-dom', './AppContext.es', './components/toast/ToastContext.es', './pages/custom-object/ListCustomObjects.es', './pages/custom-object/ViewCustomObject.es'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = void 0;

  var _modal = require("@frontend-taglib-clay$clayui/modal");

  var _react = _interopRequireDefault(require("frontend-js-react-web$react"));

  var _reactDnd = require("frontend-js-react-web$react-dnd");

  var _reactDndHtml5Backend = _interopRequireDefault(require("frontend-js-react-web$react-dnd-html5-backend"));

  var _reactRouterDom = require("app-builder-web$react-router-dom");

  var _AppContext = require("./AppContext.es");

  var _ToastContext = require("./components/toast/ToastContext.es");

  var _ListCustomObjects = _interopRequireDefault(require("./pages/custom-object/ListCustomObjects.es"));

  var _ViewCustomObject = _interopRequireDefault(require("./pages/custom-object/ViewCustomObject.es"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  /**
   * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
   *
   * This library is free software; you can redistribute it and/or modify it under
   * the terms of the GNU Lesser General Public License as published by the Free
   * Software Foundation; either version 2.1 of the License, or (at your option)
   * any later version.
   *
   * This library is distributed in the hope that it will be useful, but WITHOUT
   * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
   * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
   * details.
   */
  var _default = (0, _reactDnd.DragDropContext)(_reactDndHtml5Backend["default"])(function (props) {
    return _react["default"].createElement(_AppContext.AppContextProvider, props, _react["default"].createElement(_ToastContext.ToastContextProvider, null, _react["default"].createElement(_modal.ClayModalProvider, null, _react["default"].createElement(_reactRouterDom.HashRouter, null, _react["default"].createElement("div", {
      className: "custom-object-app"
    }, _react["default"].createElement(_reactRouterDom.Switch, null, _react["default"].createElement(_reactRouterDom.Route, {
      component: _ListCustomObjects["default"],
      exact: true,
      path: "/"
    }), _react["default"].createElement(_reactRouterDom.Route, {
      component: _ViewCustomObject["default"],
      path: "/custom-object/:dataDefinitionId(\\d+)"
    })))))));
  });

  exports["default"] = _default;
  //# sourceMappingURL=App.es.js.map
});
//# sourceMappingURL=App.es.js.map

==> com.liferay.app.builder.web-1.0.18.jar: META-INF/resources/js/App.es.js <==
Liferay.Loader.define("app-builder-web@1.0.18/js/App.es", ['module', 'exports', 'require', '@frontend-taglib-clay$clayui/modal', 'frontend-js-react-web$react', 'frontend-js-react-web$react-dnd', 'frontend-js-react-web$react-dnd-html5-backend', 'app-builder-web$react-router-dom', './AppContext.es', './components/toast/ToastContext.es', './pages/custom-object/ListCustomObjects.es', './pages/custom-object/ViewCustomObject.es'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = void 0;

  var _modal = require("@frontend-taglib-clay$clayui/modal");

  var _react = _interopRequireDefault(require("frontend-js-react-web$react"));

  var _reactDnd = require("frontend-js-react-web$react-dnd");

  var _reactDndHtml5Backend = _interopRequireDefault(require("frontend-js-react-web$react-dnd-html5-backend"));

  var _reactRouterDom = require("app-builder-web$react-router-dom");

  var _AppContext = require("./AppContext.es");

  var _ToastContext = require("./components/toast/ToastContext.es");

  var _ListCustomObjects = _interopRequireDefault(require("./pages/custom-object/ListCustomObjects.es"));

  var _ViewCustomObject = _interopRequireDefault(require("./pages/custom-object/ViewCustomObject.es"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  /**
   * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
   *
   * This library is free software; you can redistribute it and/or modify it under
   * the terms of the GNU Lesser General Public License as published by the Free
   * Software Foundation; either version 2.1 of the License, or (at your option)
   * any later version.
   *
   * This library is distributed in the hope that it will be useful, but WITHOUT
   * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
   * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
   * details.
   */
  var _default = function _default(props) {
    return _react["default"].createElement(_reactDnd.DndProvider, {
      backend: _reactDndHtml5Backend["default"]
    }, _react["default"].createElement(_AppContext.AppContextProvider, props, _react["default"].createElement(_ToastContext.ToastContextProvider, null, _react["default"].createElement(_modal.ClayModalProvider, null, _react["default"].createElement(_reactRouterDom.HashRouter, null, _react["default"].createElement("div", {
      className: "custom-object-app"
    }, _react["default"].createElement(_reactRouterDom.Switch, null, _react["default"].createElement(_reactRouterDom.Route, {
      component: _ListCustomObjects["default"],
      exact: true,
      path: "/"
    }), _react["default"].createElement(_reactRouterDom.Route, {
      component: _ViewCustomObject["default"],
      path: "/custom-object/:dataDefinitionId(\\d+)"
    }))))))));
  };

  exports["default"] = _default;
  //# sourceMappingURL=App.es.js.map
});
//# sourceMappingURL=App.es.js.map
